@@ -1,6 +1,8 @@
 import MultiplexHandler from "./MultiplexHandler";
 import { Handler } from "./Parser";
 
+type OptionalFunction = undefined | ((...args: unknown[]) => void);
+
 export class CollectingHandler extends MultiplexHandler {
     _cbs: Partial<Handler>;
     events: [keyof Handler, ...unknown[]][];
@@ -8,31 +10,23 @@ export class CollectingHandler extends MultiplexHandler {
     constructor(cbs: Partial<Handler> = {}) {
         super((name, ...args) => {
             this.events.push([name, ...args]);
-            // @ts-ignore
-            if (this._cbs[name]) this._cbs[name](...args);
+            (this._cbs[name] as OptionalFunction)?.(...args);
         });
 
         this._cbs = cbs;
         this.events = [];
     }
 
-    onreset() {
+    onreset(): void {
         this.events = [];
-        if (this._cbs.onreset) this._cbs.onreset();
+        this._cbs.onreset?.();
     }
 
-    restart() {
-        if (this._cbs.onreset) this._cbs.onreset();
+    restart(): void {
+        this._cbs.onreset?.();
 
-        for (let i = 0; i < this.events.length; i++) {
-            const [name, ...args] = this.events[i];
-
-            if (!this._cbs[name]) {
-                continue;
-            }
-
-            // @ts-ignore
-            this._cbs[name](...args);
+        for (const [name, ...args] of this.events) {
+            (this._cbs[name] as OptionalFunction)?.(...args);
         }
     }
 }
