@@ -1,16 +1,23 @@
-import { parseDOM, createDomStream } from ".";
+import {
+    parseDOM,
+    createDomStream,
+    DomHandler,
+    DefaultHandler,
+    RssHandler,
+} from ".";
+import { FeedHandler } from "./FeedHandler";
 import { Element } from "domhandler";
 
 // Add an `attributes` prop to the Element for now, to make it possible for Jest to render DOM nodes.
 Object.defineProperty(Element.prototype, "attributes", {
     get() {
-        return Object.keys(this.attribs).map(name => ({
+        return Object.keys(this.attribs).map((name) => ({
             name,
-            value: this.attribs[name]
+            value: this.attribs[name],
         }));
     },
     configurable: true,
-    enumerable: false
+    enumerable: false,
 });
 
 describe("Index", () => {
@@ -19,7 +26,7 @@ describe("Index", () => {
         expect(dom).toMatchSnapshot();
     });
 
-    test("createDomStream", done => {
+    test("createDomStream", (done) => {
         const domStream = createDomStream((err, dom) => {
             expect(err).toBeNull();
             expect(dom).toMatchSnapshot();
@@ -33,4 +40,11 @@ describe("Index", () => {
 
         domStream.end();
     });
+
+    describe("API", () => {
+        it("should export the appropriate APIs", () => {
+            expect(RssHandler).toEqual(FeedHandler);
+            expect(DomHandler).toEqual(DefaultHandler);
+        });
+    });
 });
